Learn R Programming

cellOrigins (version 0.1.3)

diagnosticPlots: Diagnostic plots to explore seqVsInsitu results

Description

Accepts the result of seqVsInsitu and iterating_seqVsInsitu and produces diagnostic plots. If the sequencing data fits to one or more terms or combinations of terms, then the scatterplot will cluster into foci. As the number of combined terms is increased the foci merge into fewer groups. A diagonal in the scatterplot is a sign of error.

Usage

diagnosticPlots(seqVsInsitu_results)

Arguments

seqVsInsitu_results

Value

None.

Examples

Run this code
# NOT RUN {
fpath <- system.file("extdata", "vncMedianCoverage.tsv", package="cellOrigins")
vncExpression <- read.delim(file = fpath, header=FALSE, as.is=TRUE)

expression <- vncExpression$V2
names(expression) <- vncExpression$V1

result <- seqVsInsitu(expression, depth=1)
diagnosticPlots(result)

# }
# NOT RUN {
oracleResponse <- iterating_seqVsInsitu(expression, 3)
diagnosticPlots(oracleResponse)
# }

Run the code above in your browser using DataLab