Learn R Programming

cellOrigins (version 0.1.3)

vncMedianCoverage.tsv: Drosophila melanogaster embryo ventral nerve cord RNASeq coverage

Description

Median RNAseq read coverages from 3 dissected embryonic (stage 11) fruit fly ventral nerve cords. The sequencing coverages are measured within the probing intervals of high-confidence BDGP insitu probes, as described in cellOrigins-package.

Arguments

Format

The format is: probe name, coverage, chromosome, probe beginn, probe end, strand.

Examples

Run this code
# NOT RUN {
  fpath <- system.file("extdata", "vncMedianCoverage.tsv", package="cellOrigins")
vncExpression <- read.delim(file = fpath, header=FALSE, as.is=TRUE)
# }

Run the code above in your browser using DataLab